flutter_responsive_debugger library

Classes

DeviceConfig
Represents a device configuration for simulation
Devices
Predefined device configurations
ResponsiveDebugger
A developer-only overlay tool to interactively test Flutter app responsiveness across different screen sizes, font scales, safe areas, and orientations.

Enums

DebuggerSection
Control panel sections for organization
DebugOrientation
Device orientation options
DebugPlatform
Supported platform types for simulation
DeviceCategory
Predefined device categories
FontScalePreset
Font scale presets
VisualDebugOption
Visual debugging options