DebuggerSection enum

Control panel sections for organization

Inheritance
Available extensions

Values

deviceSelection → const DebuggerSection
const DebuggerSection('Device Selection', 'device_selection')
orientation → const DebuggerSection
const DebuggerSection('Orientation', 'orientation')
fontScale → const DebuggerSection
const DebuggerSection('Font Scale', 'font_scale')
visualOptions → const DebuggerSection
const DebuggerSection('Visual Options', 'visual_options')
platformOverride → const DebuggerSection
const DebuggerSection('Platform Override', 'platform_override')
customSettings → const DebuggerSection
const DebuggerSection('Custom Settings', 'custom_settings')

Properties

displayName String
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DebuggerSection>
A constant List of the values in this enum, in order of their declaration.